<template>
  <InfiniteLoading scrollViewClassName="common-infinite-scroll-list" v-bind="infiniteLoadingProps">
    <template #renderItem="{ item }">
      <FlexJobCard>
        <template #footerLeft>
          <div class="flexJob-card-footer-text">已录用</div>
        </template>
        <template #footerRight>
          <nut-button type="primary" @click="goToJobDetail(item.id)">查看详情</nut-button>
        </template>
      </FlexJobCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { OrderInputType } from '@12333/constants';
import { RouterPath } from '@/constants';
import { useInfiniteLoading } from '@12333/hooks';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import { FlexJobCard } from '@12333/components';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'SignList',
});

// type Props = {};

// const props = withDefaults(defineProps<Props>(), {});

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'isRecommend', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskByArrange(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskByArrange'],
  }
);

function goToJobDetail(id: string) {
  Taro.navigateTo({
    url: `${RouterPath.flexJobDetailFromTask}?id=${id}`,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
